# Changelog

## [0.1.4](https://github.com/snakemake/snakemake-scheduler-plugin-firstfit/compare/v0.1.3...v0.1.4) (2026-03-12)


### Bug Fixes

* doc tweaks ([#12](https://github.com/snakemake/snakemake-scheduler-plugin-firstfit/issues/12)) ([f19066b](https://github.com/snakemake/snakemake-scheduler-plugin-firstfit/commit/f19066bed63d6cf997acbf85e3af35472207171e))

## [0.1.3](https://github.com/snakemake/snakemake-scheduler-plugin-firstfit/compare/v0.1.2...v0.1.3) (2025-11-18)


### Documentation

* remove emails ([#10](https://github.com/snakemake/snakemake-scheduler-plugin-firstfit/issues/10)) ([06889bb](https://github.com/snakemake/snakemake-scheduler-plugin-firstfit/commit/06889bb06edbebf482746d88353bf38f27044f8b))
* repo URL ([#8](https://github.com/snakemake/snakemake-scheduler-plugin-firstfit/issues/8)) ([eb6f3da](https://github.com/snakemake/snakemake-scheduler-plugin-firstfit/commit/eb6f3da1ecc394d5c186582b9792743dcb1b3122))

## [0.1.2](https://github.com/snakemake/snakemake-scheduler-plugin-firstfit/compare/v0.1.1...v0.1.2) (2025-10-20)


### Bug Fixes

* python build ([#6](https://github.com/snakemake/snakemake-scheduler-plugin-firstfit/issues/6)) ([860e1ff](https://github.com/snakemake/snakemake-scheduler-plugin-firstfit/commit/860e1ff365af224015af038246978dbf35658600))

## [0.1.1](https://github.com/snakemake/snakemake-scheduler-plugin-firstfit/compare/v0.1.0...v0.1.1) (2025-10-20)


### Bug Fixes

* update scheduler interface ([#4](https://github.com/snakemake/snakemake-scheduler-plugin-firstfit/issues/4)) ([d61750b](https://github.com/snakemake/snakemake-scheduler-plugin-firstfit/commit/d61750b2bf97559532ec695ca0405f4d8b9fbf85))

## 0.1.0 (2025-10-20)


### Features

* trigger first release ([#2](https://github.com/snakemake/snakemake-scheduler-plugin-firstfit/issues/2)) ([f890cfb](https://github.com/snakemake/snakemake-scheduler-plugin-firstfit/commit/f890cfb180cba1c53df6ece02ac112096df91caa))
